@@ -26,12 +26,14 @@ from twisted.python import failure
 from twisted.python import log
 
 import buildbot
-import buildbot.pbmanager
 from buildbot import config
 from buildbot import monkeypatches
 from buildbot.buildbot_net_usage_data import sendBuildbotNetUsageData
 from buildbot.changes.manager import ChangeManager
+from buildbot.config.master import FileLoader
+from buildbot.config.master import MasterConfig
 from buildbot.data import connector as dataconnector
+from buildbot.data import graphql
 from buildbot.db import connector as dbconnector
 from buildbot.db import exceptions
 from buildbot.machine.manager import MachineManager
@@ -43,12 +45,13 @@ from buildbot.process.botmaster import BotMaster
 from buildbot.process.users.manager import UserManagerManager
 from buildbot.schedulers.manager import SchedulerManager
 from buildbot.secrets.manager import SecretManager
-from buildbot.status.master_compat import Status
 from buildbot.util import check_functional_environment
 from buildbot.util import service
 from buildbot.util.eventual import eventually
 from buildbot.wamp import connector as wampconnector
 from buildbot.worker import manager as workermanager
+from buildbot.worker.protocols.manager.msgpack import MsgManager
+from buildbot.worker.protocols.manager.pb import PBManager
 from buildbot.www import service as wwwservice
 
 
@@ -87,7 +90,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         if config_loader is None:
             if configFileName is None:
                 configFileName = 'master.cfg'
-            config_loader = config.FileLoader(self.basedir, configFileName)
+            config_loader = FileLoader(self.basedir, configFileName)
         self.config_loader = config_loader
         self.configFileName = configFileName
 
@@ -102,7 +105,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.configured_db_url = None
 
         # configuration / reconfiguration handling
-        self.config = config.MasterConfig()
+        self.config = MasterConfig()
         self.config_version = 0  # increased by one on each reconfig
         self.reconfig_active = False
         self.reconfig_requested = False
@@ -125,7 +128,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             self.hostname = socket.getfqdn()
 
         # public attributes
-        self.name = ("{}:{}".format(self.hostname, os.path.abspath(self.basedir or '.')))
+        self.name = (f"{self.hostname}:{os.path.abspath(self.basedir or '.')}")
         if isinstance(self.name, bytes):
             self.name = self.name.decode('ascii', 'replace')
         self.masterid = None
@@ -141,9 +144,12 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.caches = cache.CacheManager()
         yield self.caches.setServiceParent(self)
 
-        self.pbmanager = buildbot.pbmanager.PBManager()
+        self.pbmanager = PBManager()
         yield self.pbmanager.setServiceParent(self)
 
+        self.msgmanager = MsgManager()
+        yield self.msgmanager.setServiceParent(self)
+
         self.workers = workermanager.WorkerManager(self)
         yield self.workers.setServiceParent(self)
 
@@ -174,15 +180,15 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.data = dataconnector.DataConnector()
         yield self.data.setServiceParent(self)
 
+        self.graphql = graphql.GraphQLConnector()
+        yield self.graphql.setServiceParent(self)
+
         self.www = wwwservice.WWWService()
         yield self.www.setServiceParent(self)
 
         self.debug = debug.DebugServices()
         yield self.debug.setServiceParent(self)
 
-        self.status = Status()
-        yield self.status.setServiceParent(self)
-
         self.secrets_manager = SecretManager()
         yield self.secrets_manager.setServiceParent(self)
         self.secrets_manager.reconfig_priority = 2000
@@ -219,7 +225,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
             yield self._services_d
             self._services_d = None
 
-        log.msg("Starting BuildMaster -- buildbot.version: {}".format(buildbot.version))
+        log.msg(f"Starting BuildMaster -- buildbot.version: {buildbot.version}")
 
         # Set umask
         if self.umask is not None:
@@ -369,11 +375,11 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
         self.reconfig_active = self.reactor.seconds()
         metrics.MetricCountEvent.log("loaded_config", 1)
 
-        # notify every 10 seconds that the reconfig is still going on, although
-        # reconfigs should not take that long!
+        # notify every 10 seconds that the reconfig is still going on, the duration of reconfigs is
+        # longer on larger installations and may take a while.
         self.reconfig_notifier = task.LoopingCall(
-            lambda: log.msg("reconfig is ongoing for {} s".format(self.reactor.seconds() -
-                                                                  self.reconfig_active)))
+            lambda: log.msg("reconfig is ongoing for "
+                            f"{self.reactor.seconds() - self.reconfig_active:.3f} s"))
         self.reconfig_notifier.start(10, now=False)
 
         timer = metrics.Timer("BuildMaster.reconfig")
@@ -395,6 +401,7 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
     @defer.inlineCallbacks
     def doReconfig(self):
         log.msg("beginning configuration update")
+        time_started = self.reactor.seconds()
         changes_made = False
         failed = False
         try:
@@ -423,17 +430,18 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
 
         if failed:
             if changes_made:
-                log.msg("WARNING: reconfig partially applied; master "
-                        "may malfunction")
+                msg = "WARNING: configuration update partially applied; master may malfunction"
             else:
-                log.msg("reconfig aborted without making any changes")
+                msg = "configuration update aborted without making any changes"
         else:
-            log.msg("configuration update complete")
+            msg = "configuration update complete"
+
+        log.msg(f"{msg} (took {(self.reactor.seconds() - time_started):.3f} seconds)")
 
     def reconfigServiceWithBuildbotConfig(self, new_config):
         if self.configured_db_url is None:
             self.configured_db_url = new_config.db['db_url']
-        elif (self.configured_db_url != new_config.db['db_url']):
+        elif self.configured_db_url != new_config.db['db_url']:
             config.error(
                 "Cannot change c['db']['db_url'] after the master has started",
             )
@@ -449,12 +457,6 @@ class BuildMaster(service.ReconfigurableServiceMixin, service.MasterService):
     def allSchedulers(self):
         return list(self.scheduler_manager)
 
-    def getStatus(self):
-        """
-        @rtype: L{buildbot.status.builder.Status}
-        """
-        return self.status
-
     # state maintenance (private)
     def getObjectId(self):
         """
