@@ -28,10 +28,10 @@ from buildbot.changes import gerritchangesource
 from buildbot.test import fakedb
 from buildbot.test.fake import httpclientservice as fakehttpclientservice
 from buildbot.test.fake.change import Change
+from buildbot.test.reactor import TestReactorMixin
+from buildbot.test.runprocess import ExpectMasterShell
+from buildbot.test.runprocess import MasterRunProcessMixin
 from buildbot.test.util import changesource
-from buildbot.test.util.misc import TestReactorMixin
-from buildbot.test.util.runprocess import ExpectMaster
-from buildbot.test.util.runprocess import MasterRunProcessMixin
 
 
 class TestGerritHelpers(unittest.TestCase):
@@ -93,7 +93,7 @@ class TestGerritChangeSource(MasterRunProcessMixin, changesource.ChangeSourceMix
                              unittest.TestCase):
 
     def setUp(self):
-        self.setUpTestReactor()
+        self.setup_test_reactor()
         self.setup_master_run_process()
         return self.setUpChangeSource()
 
@@ -354,7 +354,7 @@ class TestGerritChangeSource(MasterRunProcessMixin, changesource.ChangeSourceMix
             'committer': None,
             'revision': '56785678',
             'when_timestamp': None,
-            'branch': 'refs/heads/master',
+            'branch': 'master',
             'category': 'ref-updated',
             'revlink': '',
             'properties': {
@@ -547,9 +547,9 @@ class TestGerritChangeSource(MasterRunProcessMixin, changesource.ChangeSourceMix
         ]
 
         self.expect_commands(
-            ExpectMaster(exp_argv)
+            ExpectMasterShell(exp_argv)
             .stdout(self.query_files_success),
-            ExpectMaster(exp_argv)
+            ExpectMasterShell(exp_argv)
             .stdout(self.query_files_failure)
         )
 
@@ -564,7 +564,7 @@ class TestGerritChangeSource(MasterRunProcessMixin, changesource.ChangeSourceMix
     @defer.inlineCallbacks
     def test_getFilesFromEvent(self):
         self.expect_commands(
-            ExpectMaster(['ssh', '-o', 'BatchMode=yes', 'user@host', '-p', '29418', 'gerrit',
+            ExpectMasterShell(['ssh', '-o', 'BatchMode=yes', 'user@host', '-p', '29418', 'gerrit',
                           'query', '4321', '--format', 'JSON', '--files', '--patch-sets'])
             .stdout(self.query_files_success)
         )
@@ -590,7 +590,7 @@ class TestGerritEventLogPoller(changesource.ChangeSourceMixin,
 
     @defer.inlineCallbacks
     def setUp(self):
-        self.setUpTestReactor()
+        self.setup_test_reactor()
         yield self.setUpChangeSource()
         yield self.master.startService()
 
