@@ -24,8 +24,8 @@ from twisted.trial import unittest
 from buildbot.process.builder import Builder
 from buildbot.reporters.generators.buildrequest import BuildRequestGenerator
 from buildbot.test.fake import fakemaster
+from buildbot.test.reactor import TestReactorMixin
 from buildbot.test.util.config import ConfigErrorsMixin
-from buildbot.test.util.misc import TestReactorMixin
 from buildbot.test.util.reporter import ReporterTestMixin
 
 
@@ -35,7 +35,7 @@ class TestBuildRequestGenerator(ConfigErrorsMixin, TestReactorMixin,
     all_messages = ('failing', 'passing', 'warnings', 'exception', 'cancelled')
 
     def setUp(self):
-        self.setUpTestReactor()
+        self.setup_test_reactor()
         self.setup_reporter_test()
         self.master = fakemaster.make_master(self, wantData=True, wantDb=True,
                                              wantMq=True)
@@ -83,6 +83,7 @@ class TestBuildRequestGenerator(ConfigErrorsMixin, TestReactorMixin,
         report = yield g.buildrequest_message(self.master, build)
 
         g.formatter.format_message_for_build.assert_called_with(self.master, build,
+                                                                is_buildset=True,
                                                                 mode=self.all_messages,
                                                                 users=[])
 
