@@ -56,14 +56,14 @@ def gitDescribeToPep440(version):
 def mTimeVersion(init_file):
     cwd = os.path.dirname(os.path.abspath(init_file))
     m = 0
-    for root, dirs, files in os.walk(cwd):
+    for root, _, files in os.walk(cwd):
         for f in files:
             m = max(os.path.getmtime(os.path.join(root, f)), m)
     d = datetime.datetime.utcfromtimestamp(m)
     return d.strftime("%Y.%m.%d")
 
 
-def getVersionFromArchiveId(git_archive_id='1634372192  (HEAD -> master, tag: v3.4.0)'):
+def getVersionFromArchiveId(git_archive_id='1646575761  (HEAD -> master, tag: v3.5.0)'):
     """ Extract the tag if a source is from git archive.
 
         When source is exported via `git archive`, the git_archive_id init value is modified
